@@ -1,5 +1,5 @@
 # This file is part of fedmsg.
-# Copyright (C) 2012 Red Hat, Inc.
+# Copyright (C) 2012, 2013 Red Hat, Inc.
 #
 # fedmsg is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -16,7 +16,9 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 #
 # Authors:  Ralph Bean <rbean@redhat.com>
-#
+#           Luke Macken <lmacken@redhat.com>
+
+from fasshim import gravatar_url
 from fedmsg_meta_fedora_infrastructure import BaseProcessor
 
 
@@ -37,9 +39,12 @@ class BadgesProcessor(BaseProcessor):
         tmpl = self._('{user} has been awarded the "{name}" badge')
         return tmpl.format(user=user, name=name)
 
-    def secondary_icon(self, msg, **config):
+    def icon(self, msg, **config):
         return msg['msg']['badge']['image_url']
 
+    def secondary_icon(self, msg, **config):
+        return gravatar_url(msg['msg']['user']['username'])
+
     def usernames(self, msg, **config):
         return set([msg['msg']['user']['username']])
 
