@@ -30,11 +30,14 @@ class TestNewBadge(Base):
     Contributors by the fedbadges backend.
     """
 
-    expected_title = "fedbadges.badge.award (unsigned)"
+    expected_title = "fedbadges.badge.award"
     expected_subti = 'ralph has been awarded the ' + \
         '"Something on your mind" badge'
     expected_link = "https://badges.fedoraproject.org/user/ralph"
-    expected_secondary_icon = "http://example.com/image.png"
+    expected_icon = "http://example.com/image.png"
+    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
+        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
+        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
     expected_packages = set([])
     expected_usernames = set(['ralph'])
     expected_objects = set(['something-on-your-mind'])
